# Table of Contents

- [creating-survey](<./creating-survey.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Creating a Survey](<./Creating-a-Survey.md>)
  - [Introduction](<./Creating-a-Survey/Introduction.md>)
  - [Defining the Scope of a Survey](<./Creating-a-Survey/Defining-the-Scope-of-a-Survey.md>)
  - [Designing a Survey](<./Creating-a-Survey/Designing-a-Survey.md>)
  - [Designing a Survey From Scratch](<./Creating-a-Survey/Designing-a-Survey-From-Scratch.md>)
  - [Fact Sheet Fields](<./Creating-a-Survey/Fact-Sheet-Fields.md>)
  - [Basic Fields](<./Creating-a-Survey/Basic-Fields.md>)
  - [Advanced Fields](<./Creating-a-Survey/Advanced-Fields.md>)
  - [Adding Links and Descriptions](<./Creating-a-Survey/Adding-Links-and-Descriptions.md>)
  - [Making a Question Mandatory](<./Creating-a-Survey/Making-a-Question-Mandatory.md>)
  - [Deleting Questions](<./Creating-a-Survey/Deleting-Questions.md>)
  - [Designing a Survey from Existing Survey and Survey Template](<./Creating-a-Survey/Designing-a-Survey-from-Existing-Survey-and-Survey-Template.md>)
  - [Importing and Exporting a Survey](<./Creating-a-Survey/Importing-and-Exporting-a-Survey.md>)
  - [Adding SAP LeanIX Store Templates to the Workspace](<./Creating-a-Survey/Adding-SAP-LeanIX-Store-Templates-to-the-Workspace.md>)
  - [Creating a Fresh Survey Run from a Finished Survey](<./Creating-a-Survey/Creating-a-Fresh-Survey-Run-from-a-Finished-Survey.md>)
